@@ -1,8 +1,8 @@
 """Main module of this project."""
 
+import datetime
 from .expr_utils import Node, build_node
 from .problem_utils import Problem
-import datetime
 
 
 class FTPtsGame(object):
@@ -23,13 +23,12 @@ class FTPtsGame(object):
     solve(): put forward a solution and show solution intervals. (+)
     """
 
-    def __init__(self, target=42):
+    def __init__(self):
         """Start the game session, serving as an initialization."""
         self.__valid = []  # this list stores readable answers
         self.__formula = []  # this list stores converted formulas
         self.__players = []  # this list stores player statistics
         self.__playing = False  # this stores playing status
-        self.__target = target
 
     def __status_check(self, required_status: bool = True):
         """A status checker."""
@@ -46,15 +45,21 @@ class FTPtsGame(object):
         elapsed = datetime.datetime.now() - self.__timer
         return elapsed
 
-    def generate_problem(self, problem):
+    def generate_problem(self, problem, target=42):
         """Generate a problem manually."""
         self.__status_check(required_status=False)
+        self.__target = target
         self.__problem = tuple(sorted(problem))
         self.__problem_class = Problem(list(self.__problem))
         self.__problem_class.generate_answers(self.__target)
         if len(self.__problem_class.distinct_answer_table) == 0:
             raise ValueError('No solution found.')
 
+    def get_current_target(self) -> int:
+        """Get current target. Effective when playing."""
+        self.__status_check(required_status=True)
+        return self.__target
+
     def get_current_problem(self) -> tuple:
         """Get current problem. Effective when playing."""
         self.__status_check(required_status=True)
@@ -81,12 +86,10 @@ class FTPtsGame(object):
         current_solution_set = set()
         for expr_str in self.__valid:
             node = build_node(expr_str)
-            current_solution_set.add(
-                self.__problem_class.equivalence_dict[node.unique_id()])
+            current_solution_set.add(self.__problem_class.equivalence_dict[node.unique_id()])
         return_list = []
         for expr in self.__problem_class.distinct_answer_table:
-            if self.__problem_class.equivalence_dict[
-                    expr.unique_id()] not in current_solution_set:
+            if self.__problem_class.equivalence_dict[expr.unique_id()] not in current_solution_set:
                 return_list.append(str(expr))
         return return_list
 
@@ -100,8 +103,7 @@ class FTPtsGame(object):
         class_id = self.__problem_class.equivalence_dict[node.unique_id()]
         for ind in range(0, len(self.__formula)):
             cmp_node = self.__formula[ind]
-            cmp_class_id = self.__problem_class.equivalence_dict[
-                cmp_node.unique_id()]
+            cmp_class_id = self.__problem_class.equivalence_dict[cmp_node.unique_id()]
             if cmp_class_id == class_id:
                 raise LookupError(self.__valid[ind])
 
@@ -110,8 +112,14 @@ class FTPtsGame(object):
         self.__status_check(required_status=True)
 
         replace_table = [
-            ('×', '*'), ('x', '*'), ('÷', '/'), (' ', ''),
-            ('\n', ''), ('\r', ''), ('（', '('), ('）', ')'),
+            ('×', '*'),
+            ('x', '*'),
+            ('÷', '/'),
+            (' ', ''),
+            ('\n', ''),
+            ('\r', ''),
+            ('（', '('),
+            ('）', ')'),
         ]
         for src, dest in replace_table:
             math_expr = math_expr.replace(src, dest)
